@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -36,7 +36,11 @@ SOFTWARE.
 #ifdef HIP_COMPILE
     #include <hip/hip_fp16.h>
 #endif // HIP_COMPILE
-#include <half/half.hpp>
+#if __has_include(<half/half.hpp>)
+    #include <half/half.hpp>
+#else
+    #include <half.hpp>
+#endif
 using halfhpp = half_float::half;
 typedef halfhpp Rpp16f;
 
@@ -164,9 +168,23 @@ typedef enum
     /*! \brief Number of src dims is invalid. (Needs to adhere to function specification.) \ingroup group_rppdefs */
     RPP_ERROR_INVALID_SRC_DIMS          = -23,
     /*! \brief Number of dst dims is invalid. (Needs to adhere to function specification.) \ingroup group_rppdefs */
-    RPP_ERROR_INVALID_DST_DIMS          = -24
+    RPP_ERROR_INVALID_DST_DIMS          = -24,
+    /*! \brief Length in some dimensions are invalid. (Needs to adhere to function specification.) \ingroup group_rppdefs */
+    RPP_ERROR_INVALID_DIM_LENGTHS       = -25,
+    /*! \brief The specified axis is invalid or out of range. (Needs to adhere to function specification.) \ingroup group_rppdefs */
+    RPP_ERROR_INVALID_AXIS              = -26
 } RppStatus;
 
+/*! \brief RPP RppBackend type enums
+ * \ingroup group_rppdefs
+ */
+typedef enum
+{
+    RPP_HOST_BACKEND,
+    RPP_HIP_BACKEND,
+    RPP_OCL_BACKEND
+} RppBackend;
+
 /*! \brief RPP rppStatus_t type enums
  * \ingroup group_rppdefs
  */
@@ -183,6 +201,7 @@ typedef enum
     rppStatusUnsupportedOp  = -8,
 } rppStatus_t;
 
+#ifdef LEGACY_SUPPORT
 /*! \brief RPP Operations type enum
  * \ingroup group_rppdefs
  */
@@ -224,6 +243,7 @@ typedef struct
     Rpp32f rho;
     Rpp32f theta;
 } RppPointPolar;
+#endif
 
 /*! \brief RPP layout params
  * \ingroup group_rppdefs
@@ -268,6 +288,7 @@ typedef struct
 
 /******************** RPPI typedefs ********************/
 
+#ifdef LEGACY_SUPPORT
 /*! \brief RPPI Image color convert mode type enum
  * \ingroup group_rppdefs
  */
@@ -287,15 +308,6 @@ typedef enum
     RPPI_HIGH
 } RppiFuzzyLevel;
 
-/*! \brief RPPI Image channel format type enum
- * \ingroup group_rppdefs
- */
-typedef enum
-{
-    RPPI_CHN_PLANAR,
-    RPPI_CHN_PACKED
-} RppiChnFormat;
-
 /*! \brief RPP Image axis type enum
  * \ingroup group_rppdefs
  */
@@ -337,34 +349,6 @@ typedef enum
     HSV
 } RppiFormat;
 
-/*! \brief RPPI Image size(Width/Height dimensions) type struct
- * \ingroup group_rppdefs
- */
-typedef struct
-{
-    unsigned int width;
-    unsigned int height;
-} RppiSize;
-
-/*! \brief RPPI Image 2D cartesian point type struct
- * \ingroup group_rppdefs
- */
-typedef struct
-{
-    int x;
-    int y;
-} RppiPoint;
-
-/*! \brief RPPI Image 3D point type struct
- * \ingroup group_rppdefs
- */
-typedef struct
-{
-    int x;
-    int y;
-    int z;
-} RppiPoint3D;
-
 /*! \brief RPPI Image 2D Rectangle (XYWH format) type struct
  * \ingroup group_rppdefs
  */
@@ -375,6 +359,25 @@ typedef struct
     int width;
     int height;
 } RppiRect;
+#endif
+
+/*! \brief RPPI Image channel format type enum
+ * \ingroup group_rppdefs
+ */
+typedef enum
+{
+    RPPI_CHN_PLANAR,
+    RPPI_CHN_PACKED
+} RppiChnFormat;
+
+/*! \brief RPPI Image size(Width/Height dimensions) type struct
+ * \ingroup group_rppdefs
+ */
+typedef struct
+{
+    unsigned int width;
+    unsigned int height;
+} RppiSize;
 
 /*! \brief RPPI Image 2D ROI (XYWH format) type struct
  * \ingroup group_rppdefs
@@ -397,7 +400,8 @@ typedef enum
     U8,
     F32,
     F16,
-    I8
+    I8,
+    I16
 } RpptDataType;
 
 /*! \brief RPPT Tensor layout type enum
@@ -464,6 +468,16 @@ typedef enum
     REFLECT
 } RpptAudioBorderType;
 
+/*! \brief RPPT Image Border Type
+ * \ingroup group_rppdefs
+ */
+typedef enum
+{
+    REPLICATE = 0,     // Similar to Nearest Neighbors Padding
+    CONSTANT,          // Unsupported Border Type
+    REFLECT_NO_EDGE    // Unsupported Border Type
+} RpptImageBorderType;
+
 /*! \brief RPPT Mel Scale Formula
  * \ingroup group_rppdefs
  */
@@ -473,12 +487,31 @@ typedef enum
     HTK,         // Follows O’Shaughnessy’s book formula, consistent with Hidden Markov Toolkit(HTK), m = 2595 * log10(1 + (f/700))
 } RpptMelScaleFormula;
 
+/*! \brief RPPT Image 2D cartesian point type struct
+ * \ingroup group_rppdefs
+ */
+typedef struct
+{
+    int x;
+    int y;
+} RpptPoint2D;
+
+/*! \brief RPPT Image 3D point type struct
+ * \ingroup group_rppdefs
+ */
+typedef struct
+{
+    int x;
+    int y;
+    int z;
+} RpptPoint3D;
+
 /*! \brief RPPT Tensor 2D ROI LTRB struct
  * \ingroup group_rppdefs
  */
 typedef struct
 {
-    RppiPoint lt, rb;    // Left-Top point and Right-Bottom point
+    RpptPoint2D lt, rb;    // Left-Top point and Right-Bottom point
 
 } RpptRoiLtrb;
 
@@ -487,9 +520,9 @@ typedef struct
  */
 typedef struct
 {
-    RppiPoint r;
-    RppiPoint g;
-    RppiPoint b;
+    RpptPoint2D r;
+    RpptPoint2D g;
+    RpptPoint2D b;
 } RpptChannelOffsets;
 
 /*! \brief RPPT Tensor 3D ROI LTFRBB struct
@@ -497,7 +530,7 @@ typedef struct
  */
 typedef struct
 {
-    RppiPoint3D ltf, rbb; // Left-Top-Front point and Right-Bottom-Back point
+    RpptPoint3D ltf, rbb; // Left-Top-Front point and Right-Bottom-Back point
 
 } RpptRoiLtfrbb;
 
@@ -506,7 +539,7 @@ typedef struct
  */
 typedef struct
 {
-    RppiPoint xy;
+    RpptPoint2D xy;
     int roiWidth, roiHeight;
 
 } RpptRoiXywh;
@@ -516,7 +549,7 @@ typedef struct
  */
 typedef struct
 {
-    RppiPoint3D xyz;
+    RpptPoint3D xyz;
     int roiWidth, roiHeight, roiDepth;
 
 } RpptRoiXyzwhd;
