@@ -29,7 +29,7 @@ int main(int argc, char * argv[])
     // Handle inputs
     const int MIN_ARG_COUNT = 11;
 
-    int layoutType, testCase, testType, qaFlag, numRuns, batchSize, inputBitDepth;
+    int layoutType, testCase, testType, qaFlag, numRuns, batchSize, BitDepthTestMode;
     char *headerFile, *dataFile, *dstPath;
 
     if (argc < MIN_ARG_COUNT)
@@ -47,7 +47,7 @@ int main(int argc, char * argv[])
     testType = atoi(argv[7]); // 0 - unit test / 1 - performance test
     qaFlag = atoi(argv[8]); //0 - QA disabled / 1 - QA enabled
     batchSize = atoi(argv[9]);
-    inputBitDepth = atoi(argv[10]);
+    BitDepthTestMode = atoi(argv[10]);
     string scriptPath = argv[11];
 
     bool nonQACase = (testCase == 6);
@@ -66,7 +66,7 @@ int main(int argc, char * argv[])
     string funcName = augmentationMap[testCase];
     if (funcName.empty())
     {
-        if (testType == 0)
+        if (testType == UNIT_TEST) // unit test mode
             cout << "\ncase " << testCase << " is not supported\n";
 
         return RPP_ERROR_NOT_IMPLEMENTED;
@@ -111,12 +111,12 @@ int main(int argc, char * argv[])
     // set src/dst generic tensor descriptors
     RpptGenericDesc descriptor3D;
     RpptGenericDescPtr descriptorPtr3D = &descriptor3D;
-    set_generic_descriptor(descriptorPtr3D, batchSize, maxX, maxY, maxZ, numChannels, offsetInBytes, layoutType, inputBitDepth);
+    set_generic_descriptor(descriptorPtr3D, batchSize, maxX, maxY, maxZ, numChannels, offsetInBytes, layoutType, BitDepthTestMode);
 
     // update funcName based on bitdepth and layout
-    if(inputBitDepth == 0)
+    if(BitDepthTestMode == U8_TO_U8)
         funcName += "_u8_";
-    else if(inputBitDepth == 2)
+    else if(BitDepthTestMode == F32_TO_F32)
         funcName += "_f32_";
     int pln1OutTypeCase = 0, outputFormatToggle = 0;
     string funcType = set_function_type(layoutType, pln1OutTypeCase, outputFormatToggle, "HIP");
@@ -168,7 +168,7 @@ int main(int argc, char * argv[])
     Rpp8u *outputU8 = NULL;
     void *d_inputU8 = NULL, *d_outputU8 = NULL;
     Rpp64u iBufferSizeU8 = iBufferSize * sizeof(Rpp8u) + descriptorPtr3D->offsetInBytes;
-    if(inputBitDepth == 0)
+    if(BitDepthTestMode == U8_TO_U8)
     {
         inputU8 = static_cast<Rpp8u *>(calloc(iBufferSizeU8, 1));
         outputU8 = static_cast<Rpp8u *>(calloc(iBufferSizeU8, 1));
@@ -223,7 +223,7 @@ int main(int argc, char * argv[])
         convert_input_niftitype_to_Rpp32f_generic(niftiDataArray, niftiHeaderTemp, inputF32 , descriptorPtr3D);
 
         // Typecast input from F32 to U8 if input bitdepth requested is U8
-        if (inputBitDepth == 0)
+        if (BitDepthTestMode == U8_TO_U8)
         {
             for(int i = 0; i < iBufferSizeU8; i++)
                 inputU8[i] = std::min(std::max(static_cast<unsigned char>(inputF32[i]), static_cast<unsigned char>(0)), static_cast<unsigned char>(255));
@@ -251,7 +251,7 @@ int main(int argc, char * argv[])
                     }
 
                     startWallTime = omp_get_wtime();
-                    if(inputBitDepth == 2)
+                    if(BitDepthTestMode == F32_TO_F32)
                         rppt_fused_multiply_add_scalar_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, mulTensor, addTensor, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -272,9 +272,9 @@ int main(int argc, char * argv[])
                     init_slice_voxel(descriptorPtr3D, roiGenericSrcPtr, roiTensor, anchorTensor, shapeTensor);
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 0)
+                    if (BitDepthTestMode == U8_TO_U8)
                         rppt_slice_gpu(d_inputU8, descriptorPtr3D, d_outputU8, descriptorPtr3D, anchorTensor, shapeTensor, &fillValue, enablePadding, roiTensor, handle);
-                    else if(inputBitDepth == 2)
+                    else if(BitDepthTestMode == F32_TO_F32)
                         rppt_slice_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, anchorTensor, shapeTensor, &fillValue, enablePadding, roiTensor, handle);
                     else
                         missingFuncFlag = 1;
@@ -290,7 +290,7 @@ int main(int argc, char * argv[])
                         addTensor[i] = 40;
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 2)
+                    if (BitDepthTestMode == F32_TO_F32)
                         rppt_add_scalar_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, addTensor, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -306,7 +306,7 @@ int main(int argc, char * argv[])
                         subtractTensor[i] = 40;
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 2)
+                    if (BitDepthTestMode == F32_TO_F32)
                         rppt_subtract_scalar_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, subtractTensor, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -328,9 +328,9 @@ int main(int argc, char * argv[])
                     }
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 0)
+                    if (BitDepthTestMode == U8_TO_U8)
                         rppt_flip_voxel_gpu(d_inputU8, descriptorPtr3D, d_outputU8, descriptorPtr3D, horizontalTensor, verticalTensor, depthTensor, roiGenericSrcPtr, roiTypeSrc, handle);
-                    else if(inputBitDepth == 2)
+                    else if(BitDepthTestMode == F32_TO_F32)
                         rppt_flip_voxel_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, horizontalTensor, verticalTensor, depthTensor, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -346,7 +346,7 @@ int main(int argc, char * argv[])
                         mulTensor[i] = 80;
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 2)
+                    if (BitDepthTestMode == F32_TO_F32)
                         rppt_multiply_scalar_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, mulTensor, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -367,9 +367,9 @@ int main(int argc, char * argv[])
                     }
 
                     startWallTime = omp_get_wtime();
-                    if (inputBitDepth == 0)
+                    if (BitDepthTestMode == U8_TO_U8)
                         rppt_gaussian_noise_voxel_gpu(d_inputU8, descriptorPtr3D, d_outputU8, descriptorPtr3D, meanTensor, stdDevTensor, seed, roiGenericSrcPtr, roiTypeSrc, handle);
-                    else if (inputBitDepth == 2)
+                    else if (BitDepthTestMode == F32_TO_F32)
                         rppt_gaussian_noise_voxel_gpu(d_inputF32, descriptorPtr3D, d_outputF32, descriptorPtr3D, meanTensor, stdDevTensor, seed, roiGenericSrcPtr, roiTypeSrc, handle);
                     else
                         missingFuncFlag = 1;
@@ -400,7 +400,7 @@ int main(int argc, char * argv[])
 
         // Copy output buffer to host
         CHECK_RETURN_STATUS(hipMemcpy(outputF32, d_outputF32, oBufferSizeInBytes, hipMemcpyDeviceToHost));
-        if(testType == 0)
+        if(testType == UNIT_TEST) // unit test mode
         {
             cout <<"\n\n";
             if(noOfIterations > 1)
@@ -422,7 +422,7 @@ int main(int argc, char * argv[])
                 refFile.close();
             }
 
-            if(inputBitDepth == 0)
+            if(BitDepthTestMode == U8_TO_U8)
             {
                 Rpp64u bufferLength = iBufferSize * sizeof(Rpp8u) + descriptorPtr3D->offsetInBytes;
                 CHECK_RETURN_STATUS(hipMemcpy(outputU8, d_outputU8, bufferLength, hipMemcpyDeviceToHost));
@@ -468,7 +468,7 @@ int main(int argc, char * argv[])
             /*Compare the output of the function with golden outputs only if
             1.QA Flag is set
             2.input bit depth 2 (F32)*/
-            if(qaFlag && inputBitDepth == 2  && !(nonQACase))
+            if(qaFlag && BitDepthTestMode == F32_TO_F32  && !(nonQACase))
                 compare_output(outputF32, oBufferSize, testCaseName, layoutType, descriptorPtr3D, (RpptRoiXyzwhd *)roiGenericSrcPtr, dstPath, scriptPath);
             else
             {
@@ -535,7 +535,7 @@ int main(int argc, char * argv[])
         }
     }
 
-    if(testType == 1)
+    if(testType == PERFORMANCE_TEST) // performance test mode
     {
         // Display measured times
         maxWallTime *= 1000;
@@ -560,7 +560,7 @@ int main(int argc, char * argv[])
         CHECK_RETURN_STATUS(hipHostFree(shapeTensor));
     if(roiTensor != NULL)
         CHECK_RETURN_STATUS(hipHostFree(roiTensor));
-    if(inputBitDepth == 0)
+    if(BitDepthTestMode == U8_TO_U8)
     {
         if(inputU8 != NULL)
             free(inputU8);
