@@ -220,20 +220,20 @@ void set_generic_descriptor_layout(RpptGenericDescPtr srcDescriptorPtrND, RpptGe
     }
 }
 
-// sets generic descriptor numDims, offsetInBytes,  bitdepth, dims and strides
-inline void set_generic_descriptor(RpptGenericDescPtr descriptorPtr3D, int nDim, int offsetInBytes, int bitDepth, int batchSize, Rpp32u *roiTensor)
+// sets generic descriptor numDims, offsetInBytes, bitdepth, dims and strides
+inline void set_generic_descriptor(RpptGenericDescPtr descriptorPtr3D, int nDim, int offsetInBytes, int BitDepthTestMode, int batchSize, Rpp32u *roiTensor)
 {
     descriptorPtr3D->numDims = nDim + 1;
     descriptorPtr3D->offsetInBytes = offsetInBytes;
-    if (bitDepth == 0)
+    if (BitDepthTestMode == U8_TO_U8)
         descriptorPtr3D->dataType = RpptDataType::U8;
-    else if (bitDepth == 1)
+    else if (BitDepthTestMode == F16_TO_F16)
         descriptorPtr3D->dataType = RpptDataType::F16;
-    else if (bitDepth == 2)
+    else if (BitDepthTestMode == F32_TO_F32)
         descriptorPtr3D->dataType = RpptDataType::F32;
-    else if (bitDepth == 5)
+    else if (BitDepthTestMode == I8_TO_I8)
         descriptorPtr3D->dataType = RpptDataType::I8;
-    else if (bitDepth == 6)
+    else if (BitDepthTestMode == U8_TO_I8)
         descriptorPtr3D->dataType = RpptDataType::I16;
     descriptorPtr3D->dims[0] = batchSize;
     for(int i = 1; i <= nDim; i++)
@@ -375,11 +375,11 @@ inline size_t get_size_of_data_type(RpptDataType dataType)
 }
 
 // Convert input from F32 to corresponding bit depth specified by user
-inline void convert_input_bitdepth(Rpp32f *inputF32, Rpp32f *inputF32Second, void *output, void *outputSecond, Rpp32s outputBitDepth,
+inline void convert_input_bitdepth(Rpp32f *inputF32, Rpp32f *inputF32Second, void *output, void *outputSecond, Rpp32s BitDepthTestMode,
                                    Rpp64u ioBufferSize, Rpp64u ioBufferSizeSecond, Rpp64u outputBufferSize, Rpp64u outputBufferSizeSecond,
                                    RpptGenericDescPtr srcGenericDescPtr, RpptGenericDescPtr srcDescriptorPtrNDSecond, Rpp32s testCase)
 {
-    if (outputBitDepth == 0 || outputBitDepth == 3 || outputBitDepth == 4) // U8 case
+    if (BitDepthTestMode == U8_TO_U8 || BitDepthTestMode == U8_TO_F32 || BitDepthTestMode == U8_TO_F16) // U8 case
     {
         Rpp8u *outputU8 = static_cast<Rpp8u *>(output) + srcGenericDescPtr->offsetInBytes;
         for (Rpp32s i = 0; i < ioBufferSize; i++)
@@ -392,7 +392,7 @@ inline void convert_input_bitdepth(Rpp32f *inputF32, Rpp32f *inputF32Second, voi
                 outputU8Second[i] = static_cast<Rpp8u>(std::clamp(std::round(inputF32Second[i]), 0.0f, 255.0f));
         }
     }
-    else if (outputBitDepth == 1) // F16 case
+    else if (BitDepthTestMode == F16_TO_F16) // F16 case
     {
         Rpp16f *outputF16 = reinterpret_cast<Rpp16f *>(static_cast<Rpp8u *>(output) + srcGenericDescPtr->offsetInBytes);
         for (Rpp32s i = 0; i < ioBufferSize; i++)
@@ -405,13 +405,13 @@ inline void convert_input_bitdepth(Rpp32f *inputF32, Rpp32f *inputF32Second, voi
                 outputF16Second[i] = static_cast<Rpp16f>(std::clamp(inputF32Second[i], -65504.0f, 65504.0f));
         }
     }
-    else if (outputBitDepth == 2) // F32 case (No conversion needed)
+    else if (BitDepthTestMode == F32_TO_F32) // F32 case (No conversion needed)
     {
         memcpy(output, inputF32, outputBufferSize);
         if (testCase == CONCAT)
             memcpy(outputSecond, inputF32Second, outputBufferSizeSecond);
     }
-    else if (outputBitDepth == 5) // I8 case
+    else if (BitDepthTestMode == I8_TO_I8) // I8 case
     {
         Rpp8s *outputI8 = static_cast<Rpp8s *>(output) + srcGenericDescPtr->offsetInBytes;
         for (int i = 0; i < ioBufferSize; i++)
@@ -427,13 +427,13 @@ inline void convert_input_bitdepth(Rpp32f *inputF32, Rpp32f *inputF32Second, voi
 }
 
 // Reconvert other bit depths to F32
-inline void convert_output_bitdepth_to_f32(void *output, Rpp32f *outputf32, int inputBitDepth, Rpp64u oBufferSize, Rpp64u outputBufferSize, RpptGenericDescPtr dstDescPtr)
+inline void convert_output_bitdepth_to_f32(void *output, Rpp32f *outputf32, int BitDepthTestMode, Rpp64u oBufferSize, Rpp64u outputBufferSize, RpptGenericDescPtr dstDescPtr)
 {
-    if (inputBitDepth == 2 || inputBitDepth == 3) // Already F32, direct copy
+    if (BitDepthTestMode == F32_TO_F32 || BitDepthTestMode == U8_TO_F32) // Already F32, direct copy
     {
         memcpy(outputf32, output, outputBufferSize);
     }
-    else if (inputBitDepth == 0) // U8 to F32
+    else if (BitDepthTestMode == U8_TO_U8) // U8 to F32
     {
         Rpp8u *outputTemp = static_cast<Rpp8u *>(output) + dstDescPtr->offsetInBytes;
         Rpp32f *outputf32Temp = outputf32 + dstDescPtr->offsetInBytes;
@@ -444,7 +444,7 @@ inline void convert_output_bitdepth_to_f32(void *output, Rpp32f *outputf32, int
             outputf32Temp++;
         }
     }
-    else if (inputBitDepth == 1 || inputBitDepth == 4) // F16 to F32
+    else if (BitDepthTestMode == F16_TO_F16 || BitDepthTestMode == U8_TO_F16) // F16 to F32
     {
         Rpp16f *outputf16Temp = reinterpret_cast<Rpp16f *>(static_cast<Rpp8u *>(output) + dstDescPtr->offsetInBytes);
         Rpp32f *outputf32Temp = outputf32 + dstDescPtr->offsetInBytes;
@@ -455,7 +455,7 @@ inline void convert_output_bitdepth_to_f32(void *output, Rpp32f *outputf32, int
             outputf32Temp++;
         }
     }
-    else if (inputBitDepth == 5 || inputBitDepth == 6) // I8 to F32
+    else if (BitDepthTestMode == I8_TO_I8 || BitDepthTestMode == U8_TO_I8) // I8 to F32
     {
         Rpp8s *outputi8Temp = static_cast<Rpp8s *>(output) + dstDescPtr->offsetInBytes;
         Rpp32f *outputf32Temp = outputf32 + dstDescPtr->offsetInBytes;
