@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -30,7 +30,6 @@ SOFTWARE.
 #include <opencv2/opencv.hpp>
 #include <iostream>
 #include <time.h>
-#include <filesystem.h>
 #include <omp.h>
 #include <fstream>
 #include <unistd.h>
@@ -39,6 +38,7 @@ SOFTWARE.
 #include <iomanip>
 #include "rpp.h"
 #include "nifti1.h"
+#include "rpp_test_suite_common.h"
 
 using namespace std;
 typedef int16_t NIFTI_DATATYPE;
@@ -80,21 +80,6 @@ enum Augmentation {
     GAUSSIAN_NOISE_VOXEL = 6
 };
 
-void replicate_last_file_to_fill_batch(const string& lastFilePath, vector<string>& filePathVector, vector<string>& fileNamesVector, const string& lastFileName, int noOfFiles, int batchCount)
-{
-    int remainingFiles = batchCount - (noOfFiles % batchCount);
-    std::string filePath = lastFilePath;
-    std::string fileName = lastFileName;
-    if (noOfFiles > 0 && ( noOfFiles < batchCount || noOfFiles % batchCount != 0 ))
-    {
-        for (int i = 0; i < remainingFiles; i++)
-        {
-            filePathVector.push_back(filePath);
-            fileNamesVector.push_back(fileName);
-        }
-    }
-}
-
 // Opens a folder and recursively search for .nii files
 void open_folder(const string& folderPath, vector<string>& niiFileNames, vector<string>& niiFilePath)
 {
@@ -180,13 +165,13 @@ void search_nii_files(const string& folder_path, vector<string>& niiFileNames, v
 
 // sets generic descriptor dimensions and strides of src/dst
 inline void set_generic_descriptor(RpptGenericDescPtr descriptorPtr3D, int noOfImages, int maxX, int maxY, int maxZ,
-                                  int numChannels, int offsetInBytes, int layoutType, int inputBitDepth)
+                                  int numChannels, int offsetInBytes, int layoutType, int BitDepthTestMode)
 {
     descriptorPtr3D->numDims = 5;
     descriptorPtr3D->offsetInBytes = offsetInBytes;
-    if(inputBitDepth == 0)
+    if(BitDepthTestMode == U8_TO_U8)
         descriptorPtr3D->dataType = RpptDataType::U8;
-    else if(inputBitDepth == 2)
+    else if(BitDepthTestMode == F32_TO_F32)
         descriptorPtr3D->dataType = RpptDataType::F32;
 
     if (layoutType == 0)
